defmodule DecentralisedBookIndex.Sync.AuthorSync do
  alias DecentralisedBookIndex.Metadata
  alias DecentralisedBookIndex.Metadata.Author
  alias DecentralisedBookIndex.Sync.AuthorAliasRegistrySync

  def create_update(attrs, server_id) do
    registry_info = sync_registry(attrs, server_id)

    case Metadata.get_author_by_id(attrs.id) do
      {:ok, author} ->
        attrs =
          attrs
          |> Map.delete(:id)
          |> update_registry(registry_info)
          |> Map.put(:dbi_server_id, server_id)

        author
        |> Ash.Changeset.for_update(:sync, attrs)
        |> Ash.update!(authorize?: false)

        :ok

      {:error, %Ash.Error.Query.NotFound{}} ->
        attrs =
          attrs
          |> update_registry(registry_info)
          |> Map.put(:dbi_server_id, server_id)

        Author
        |> Ash.Changeset.for_create(:sync_create, attrs)
        |> Ash.create!(authorize?: false)

        :ok
    end
  end

  defp sync_registry(attrs, server_id) do
    id = Map.get(attrs, :author_alias_registry_id, nil)

    if id != nil do
      %{id: id}
      |> AuthorAliasRegistrySync.create_update(server_id)

      {:ok, id}
    else
      {:error, :no_author_alias_registry_id}
    end
  end

  defp update_registry(attrs, registry_info) do
    case registry_info do
      {:ok, id} ->
        attrs
        |> Map.replace(:author_alias_registry_id, id)

      {:error, _} ->
        attrs
        |> Map.delete(:author_alias_registry_id)
    end
  end
end
