defmodule DecentralisedBookIndexWeb.AuthorLive.Show do
  use DecentralisedBookIndexWeb, :live_view

  alias DecentralisedBookIndex.Accounts.Role

  @impl true
  def render(assigns) do
    ~H"""
    <.header class="flex-col lg:flex-row">
      {@author.name}

      <:actions>
        <%= if @current_user != nil and Role.can_moderate?(@current_user.role) do %>
          <div class="flex flex-row gap-2">
            <.link patch={~p"/authors/#{@author}/new"}>
              <.add_button>
                Alias
              </.add_button>
            </.link>
            <.link patch={~p"/authors/#{@author}/edit"}>
              <.edit_button>
                Edit
              </.edit_button>
            </.link>
          </div>
        <% end %>
      </:actions>
    </.header>

    <div class="flex flex-wrap flex-[2_1_auto] gap-5">
      <%= if @author.avatar_url != nil do %>
        <img class="w-36 h-36 mb-3 rounded-full shadow-lg mt-14 mx-auto md:mx-0" src={@author.avatar_url} alt={"#{@author.name} image"}/>
      <% else %>
        <div class="relative w-36 h-36 overflow-hidden bg-gray-100 rounded-full dark:bg-gray-600 mt-14 mx-auto md:mx-0">
          <svg class="absolute w-36 h-36 text-gray-400" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" d="M10 9a3 3 0 100-6 3 3 0 000 6zm-7 9a7 7 0 1114 0H3z" clip-rule="evenodd"></path></svg>
        </div>
      <% end %>

      <.list class="mt-5">
        <:item title="Id">{@author.id}</:item>

        <:item title="Name">{@author.name}</:item>

        <:item title="Description">{@author.description}</:item>
      </.list>
    </div>

    <%= if @alternative_names != [] do %>
      <h2 class="mb-2 text-lg font-semibold text-gray-900 dark:text-white mt-10">Alternatives names</h2>
      <ul class="max-w-md space-y-1 text-gray-700 list-disc list-inside dark:text-white">
        <%= for alias_author <- @alternative_names do %>
          <.link navigate={~p"/authors/#{alias_author.id}"}>
            <li>
              <span class="no-underline hover:underline">
                {alias_author.name}
              </span>
            </li>
          </.link>
        <% end %>
      </ul>
    <% end %>

    <.back navigate={~p"/authors"}>Back to authors</.back>
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok, socket}
  end

  @impl true
  def handle_params(%{"id" => id}, _, socket) do
    author = Ash.get!(DecentralisedBookIndex.Metadata.Author, id, actor: socket.assigns.current_user)
    alternative_names = DecentralisedBookIndex.Metadata.get_author_alternative_names!(author)

    {:noreply,
     socket
     |> assign(:page_title, page_title(socket.assigns.live_action))
     |> assign(:author, author)
     |> assign(:alternative_names, alternative_names)
    }
  end

  defp page_title(:show), do: "Show Author"
  defp page_title(:edit), do: "Edit Author"
end
