defmodule DecentralisedBookIndexWeb.PublisherLive.Edit do
  use DecentralisedBookIndexWeb, :live_view

  alias DecentralisedBookIndex.Metadata

  @impl true
  def render(assigns) do
    ~H"""
    <.live_component
      module={DecentralisedBookIndexWeb.PublisherLive.FormComponent}
      id={(@publisher && @publisher.id) || :new}
      title={@page_title}
      current_user={@current_user}
      action={@live_action}
      publisher={@publisher}
    />
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok,
     socket
     |> assign_new(:current_user, fn -> nil end)}
  end

  @impl true
  def handle_params(params, _url, socket) do
    socket =
      socket
      |> assign(:params, params)
      |> apply_action(socket.assigns.live_action, params)

    {:noreply, socket}
  end

  defp apply_action(socket, :edit, %{"id" => id}) do
    socket
    |> assign(:page_title, "Edit Publisher")
    |> assign(
      :publisher,
      Ash.get!(Metadata.Publisher, id, actor: socket.assigns.current_user)
    )
  end

  defp apply_action(socket, :new, _params) do
    socket
    |> assign(:page_title, "New Publisher")
    |> assign(:publisher, nil)
  end

  @impl true
  def handle_info({DecentralisedBookIndexWeb.PublisherLive.FormComponent, {:saved, _publisher}}, socket) do
    {:noreply, socket}
  end
end
