defmodule DecentralisedBookIndex.Sync.DataTransformers.BidTransformerTest do
  use ExUnit.Case, async: true

  alias DecentralisedBookIndex.Sync.DataTransformers.BidTransformer

  describe "correct transformations" do
    test "a json contains correct bid information" do
      json_body =
        %{
          "data" => %{
            "attributes" => %{"bid" => "1234567890", "order" => 0, "type" => "isbn"},
            "id" => "0c0c0b3a-0410-4cb0-a7e3-b62bb392b097",
            "links" => %{},
            "meta" => %{},
            "relationships" => %{},
            "type" => "book_id"
          }
        }

      assert {:ok, bid} = BidTransformer.from_json(json_body)

      assert %{
               id: "0c0c0b3a-0410-4cb0-a7e3-b62bb392b097",
               order: 0,
               type: "isbn",
               bid: "1234567890"
             } = bid
    end

    test "a json doesn't contains bid information \"data\" attribute" do
      json_body =
        %{
          "attributes" => %{"bid" => "1234567890", "order" => 0, "type" => "isbn"},
          "id" => "0c0c0b3a-0410-4cb0-a7e3-b62bb392b097",
          "links" => %{},
          "meta" => %{},
          "relationships" => %{},
          "type" => "book_id"
        }

      assert {:ok, bid} = BidTransformer.from_json(json_body)

      assert %{
               id: "0c0c0b3a-0410-4cb0-a7e3-b62bb392b097",
               order: 0,
               type: "isbn",
               bid: "1234567890"
             } = bid
    end
  end
end
