defmodule DecentralisedBookIndex.Sync.DataTransformers.PublisherTransformerTest do
  use ExUnit.Case, async: true

  alias DecentralisedBookIndex.Sync.DataTransformers.PublisherTransformer

  describe "correct transformations" do
    test "a json contains correct publisher information" do
      json_body = %{
        "data" => %{
          "attributes" => %{
            "inserted_at" => "2025-03-21T09:20:48.791539Z",
            "name" => "Publisher",
            "updated_at" => "2025-03-21T09:20:48.791539Z"
          },
          "id" => "11349865-1b7b-454a-b999-6c4059888a78",
          "links" => %{},
          "meta" => %{},
          "relationships" => %{},
          "type" => "publisher"
        },
        "jsonapi" => %{"version" => "1.0"},
        "links" => %{
          "self" =>
            "http://localhost:4000/api/v1/json/publishers/11349865-1b7b-454a-b999-6c4059888a78"
        },
        "meta" => %{}
      }

      assert {:ok, publisher} = PublisherTransformer.from_json(json_body)

      assert %{
               id: "11349865-1b7b-454a-b999-6c4059888a78",
               name: "Publisher",
               inserted_at: "2025-03-21T09:20:48.791539Z",
               updated_at: "2025-03-21T09:20:48.791539Z"
             } = publisher
    end

    test "a json doesn't contains publisher information \"data\" attribute" do
      json_body = %{
        "attributes" => %{
          "inserted_at" => "2025-03-21T09:20:48.791539Z",
          "name" => "Publisher",
          "updated_at" => "2025-03-21T09:20:48.791539Z"
        },
        "id" => "11349865-1b7b-454a-b999-6c4059888a78",
        "links" => %{},
        "meta" => %{},
        "relationships" => %{},
        "type" => "publisher"
      }

      assert {:ok, publisher} = PublisherTransformer.from_json(json_body)

      assert %{
               id: "11349865-1b7b-454a-b999-6c4059888a78",
               name: "Publisher",
               inserted_at: "2025-03-21T09:20:48.791539Z",
               updated_at: "2025-03-21T09:20:48.791539Z"
             } = publisher
    end
  end
end
